Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AskForMode ¶
AskForMode prompts the user to select between starting the HTTP server or using the CLI
func LoadConfig ¶
LoadConfig attempts to read the configuration from a file
func SetupConfigInteractively ¶
SetupConfigInteractively prompts the user to set up input and output methods interactively, including all required fields for the selected integrations.
Types ¶
type Config ¶
type Config struct {
InputMethod string `yaml:"inputMethod"`
OutputMethod string `yaml:"outputMethod"`
InputConfig map[string]interface{} `yaml:"inputconfig"`
OutputConfig map[string]interface{} `yaml:"outputconfig"`
Validations []string `yaml:"validations"`
Transformations []string `yaml:"transformations"`
ErrorHandling ErrorHandling `yaml:"errorhandling"`
}
Config represents the entire configuration structure
type ErrorHandling ¶
type ErrorHandling struct {
Strategy string `yaml:"strategy"`
QuarantineOutput QuarantineOutput `yaml:"quarantineoutput"`
}
ErrorHandling represents the error handling configuration
type QuarantineOutput ¶
QuarantineOutput represents the quarantine output configuration
Click to show internal directories.
Click to hide internal directories.